﻿using System;
using System.Windows.Input;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace RadialMenuPrismTest.Behaviours
{
    public static class SelectionChangedToCommandBehaviour
    {
        public static ICommand GetCommand(DependencyObject obj)
        {
            return (ICommand)obj.GetValue(CommandProperty);
        }

        public static void SetCommand(DependencyObject obj, ICommand value)
        {
            if (obj != null)
            {
                obj.SetValue(CommandProperty, value);
            }
        }

        public static readonly DependencyProperty CommandProperty =
           DependencyProperty.RegisterAttached("Command", typeof(ICommand),
               typeof(SelectionChangedToCommandBehaviour),
               new PropertyMetadata(null, OnCommandChanged));

        private static void OnCommandChanged(DependencyObject d,
           DependencyPropertyChangedEventArgs e)
        {
            GridView lvb = d as GridView;
            if (lvb == null) return;

            lvb.SelectionChanged += OnSelectionChanged;
        }

        private static void OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            GridView lvb = sender as GridView;
            ICommand cmd = lvb.GetValue(SelectionChangedToCommandBehaviour.CommandProperty) as ICommand;
            if (cmd != null && cmd.CanExecute(e.AddedItems))
                cmd.Execute(e.AddedItems);
        }
    }
}
